# @self/component-test

## 0.5.35

### Dependency updates

- @gradio/video@0.20.0
- @self/build@0.5.1

## 0.5.34

### Dependency updates

- @gradio/video@0.19.0

## 0.5.33

### Dependency updates

- @gradio/video@0.18.0

## 0.5.33-dev.0

### Dependency updates

- @self/build@0.5.0-dev.1
- @gradio/video@0.17.0-dev.2

## 0.5.33-dev.0

### Dependency updates

- @gradio/video@0.17.0-dev.1
- @self/build@0.4.1-dev.0

## 0.5.33-dev.0

### Dependency updates

- @gradio/video@0.17.0-dev.0

## 0.5.32

### Dependency updates

- @self/build@0.4.0
- @gradio/video@0.16.0

## 0.5.31

### Dependency updates

- @self/build@0.3.0
- @gradio/video@0.15.1

## 0.5.31

### Dependency updates

- @gradio/video@0.15.0

## 0.5.30

### Dependency updates

- @gradio/video@0.14.24

## 0.5.29

### Dependency updates

- @gradio/video@0.14.23

## 0.5.28

### Dependency updates

- @gradio/video@0.14.22

## 0.5.27

### Dependency updates

- @gradio/video@0.14.21

## 0.5.26

### Dependency updates

- @gradio/video@0.14.20

## 0.5.25

### Dependency updates

- @gradio/video@0.14.19

## 0.5.24

### Dependency updates

- @gradio/video@0.14.18

## 0.5.23

### Dependency updates

- @gradio/video@0.14.17

## 0.5.22

### Dependency updates

- @gradio/video@0.14.16

## 0.5.21

### Dependency updates

- @gradio/video@0.14.15

## 0.5.20

### Dependency updates

- @gradio/video@0.14.14

## 0.5.19

### Dependency updates

- @gradio/video@0.14.13

## 0.5.18

### Dependency updates

- @gradio/video@0.14.12

## 0.5.17

### Dependency updates

- @gradio/video@0.14.11

## 0.5.16

### Dependency updates

- @gradio/video@0.14.10

## 0.5.15

### Dependency updates

- @gradio/video@0.14.9

## 0.5.14

### Dependency updates

- @gradio/video@0.14.8

## 0.5.13

### Dependency updates

- @gradio/video@0.14.7

## 0.5.12

### Dependency updates

- @gradio/video@0.14.6

## 0.5.11

### Dependency updates

- @gradio/video@0.14.5

## 0.5.10

### Dependency updates

- @gradio/video@0.14.4

## 0.5.9

### Dependency updates

- @gradio/video@0.14.3

## 0.5.8

### Dependency updates

- @gradio/video@0.14.2

## 0.5.7

### Dependency updates

- @gradio/video@0.14.1
- @self/build@0.2.1

## 0.5.6

### Dependency updates

- @gradio/video@0.14.0

## 0.5.5

### Dependency updates

- @gradio/video@0.13.4

## 0.5.4

### Dependency updates

- @gradio/video@0.13.3

## 0.5.3

### Dependency updates

- @gradio/video@0.13.2

## 0.5.2

### Dependency updates

- @gradio/video@0.13.1

## 0.5.1

### Dependency updates

- @gradio/video@0.13.0

## 0.5.0

### Features

- [#10132](https://github.com/gradio-app/gradio/pull/10132) [`6645518`](https://github.com/gradio-app/gradio/commit/6645518a66e01ebcd2746626a4e2a14239172e76) - Tweak Chatbot `bubble_full_width` behaviour.  Thanks @hannahblair!

### Dependency updates

- @gradio/video@0.12.1

## 0.4.2

### Dependency updates

- @gradio/video@0.12.0

## 0.4.1

### Dependency updates

- @gradio/video@0.11.9

## 0.4.0

### Features

- [#9950](https://github.com/gradio-app/gradio/pull/9950) [`fc06fe4`](https://github.com/gradio-app/gradio/commit/fc06fe41f015678a0545f4e5c99f6ae2704f0031) - Add ability to read and write from LocalStorage.  Thanks @abidlabs!

### Dependency updates

- @gradio/video@0.11.8

## 0.3.1

### Dependency updates

- @gradio/video@0.11.7

## 0.3.0

### Features

- [#9794](https://github.com/gradio-app/gradio/pull/9794) [`70bda3b`](https://github.com/gradio-app/gradio/commit/70bda3bb187a7219f4707344cf47edd0a021da19) - fix storybook build.  Thanks @pngwn!

### Dependency updates

- @gradio/video@0.11.6

## 0.2.5

### Dependency updates

- @gradio/video@0.11.5
- @self/build@0.2.0

## 0.2.4

### Dependency updates

- @gradio/video@0.11.4

## 0.2.3

### Dependency updates

- @gradio/video@0.11.3
- @self/build@0.1.1

## 0.2.2

### Dependency updates

- @gradio/video@0.11.2

## 0.2.1

### Dependency updates

- @gradio/video@0.11.1

## 0.2.0

### Features

- [#8843](https://github.com/gradio-app/gradio/pull/8843) [`6f95286`](https://github.com/gradio-app/gradio/commit/6f95286337459efbccb95c9cfac63355669df9ee) - 🔡 Update default core Gradio font
- [#8843](https://github.com/gradio-app/gradio/pull/8843) [`6f95286`](https://github.com/gradio-app/gradio/commit/6f95286337459efbccb95c9cfac63355669df9ee) - Added max lines and overflow scrollbar for `gr.Code`

### Dependencies

- @gradio/video@0.11.0

## 0.2.0-beta.7

### Dependency updates

- @gradio/video@0.11.0-beta.7
- @self/build@0.1.0-beta.3

## 0.2.0-beta.6

### Dependency updates

- @gradio/video@0.11.0-beta.6

## 0.2.0-beta.5

### Dependency updates

- @gradio/video@0.11.0-beta.5

## 0.2.0-beta.4

### Dependency updates

- @gradio/video@0.11.0-beta.4

## 0.2.0-beta.3

### Dependency updates

- @gradio/video@0.11.0-beta.3

## 0.2.0-beta.2

### Features

- [#9311](https://github.com/gradio-app/gradio/pull/9311) [`c4afdcd`](https://github.com/gradio-app/gradio/commit/c4afdcdb1f1f80c5f95ab45d527236e9364ace82) - Added max lines and overflow scrollbar for `gr.Code`.  Thanks @micpst!

### Dependency updates

- @gradio/video@0.11.0-beta.2
- @self/build@0.1.0-beta.2

## 0.1.1

### Features

- [#9187](https://github.com/gradio-app/gradio/pull/9187) [`5bf00b7`](https://github.com/gradio-app/gradio/commit/5bf00b7524ebf399b48719120a49d15bb21bd65c) - make all component SSR compatible.  Thanks @pngwn!
- [#9204](https://github.com/gradio-app/gradio/pull/9204) [`3c73f00`](https://github.com/gradio-app/gradio/commit/3c73f00e3016b16917ebfe0bad390f2dff683457) - 🔡 Update default core Gradio font.  Thanks @hannahblair!

### Dependency updates

- @gradio/video@0.11.0-beta.1

## 0.1.1-beta.0

### Fixes

- [#9163](https://github.com/gradio-app/gradio/pull/9163) [`2b6cbf2`](https://github.com/gradio-app/gradio/commit/2b6cbf25908e42cf027324e54ef2cc0baad11a91) - fix exports and generate types.  Thanks @pngwn!

### Dependency updates

- @gradio/video@0.10.4

## 0.1.0

### Features

- [#9138](https://github.com/gradio-app/gradio/pull/9138) [`de1f7a2`](https://github.com/gradio-app/gradio/commit/de1f7a2b89e8d2868c7b255bc1d6e6e5c0610d03) - Create test app for components  / SSR testing.  Thanks @pngwn!